#!/bin/sh -f
#*******************************************************************************
#
#
# "@(#) $Id: mms.sh,v 1.60 2010/07/06 "
# (modified lms v1.60 for MODS) 
# sh calls bash shell, present release is 3.2.25

# ------------- Part 1 set environments ------------------

if [ -z "$SKYCAT_VER" ]; then
       SKYCAT_VER=2.7.3; export SKYCAT_VER
fi

S_V=$SKYCAT_VER

# default instrument option
# sets instrument number to l1 if not set on command line
INSTRUMENT=${1:-m1}

# default command line options for skycat
CLS="-with_grid 1 -scrollbars 1 -rtd 0 -min_scale -8 -max_scale 8"

# command line options for skycat
# this means CLS is not used if fits-file is defined! Change!!!!!!!!
# CLO=${2:-$CLS}
CLO=${2:-""}

# default debug option
DB=${3:-false}
if [ $DB != false ]; then DB=true; fi


case $INSTRUMENT in
       m1 | M1 | mods1 | Mods1 | MODS1 | mods | Mods | MODS | m2 | M2 | mods2 | Mods2 | MODS2 )
       INSTR=MODS; if $DB; then echo " INSTR            = MODS"; fi;;
       * )
       echo "Exit : there is no $1 available; try l1 or l2"
       exit;;
esac

export INSTR

# # Test to see if the MMSROOT environment variable has been defined.
# # if not, complain and exit (with instructions for correcting it)
#
# if [ ! -n "$MMSROOT" ]
#    then
#    echo "The MMSROOT environment variable has not been defined."
#    echo "Please define MMSROOT in your login shell, e.g.,"
#    echo "   setenv MMSROOT /home/machine/user/mms"
#    echo "and try again"
#    echo "mms aborting with errors"
#    exit 1
# else
#    echo "MMSROOT=${MMSROOT}"
# fi

      # any other workstation outside the VLT - FORS environment 

      MMSROOT=${MMSROOT:-$HOME/software/MaskDesign/mms_v160};        export MMSROOT;  # where mms is installed
      ISF_DIR=$MMSROOT/lib/mos;                  export ISF_DIR;  # MODS.isf
      INS_ROOT=$HOME                             export INS_ROOT; # user home directory 
      INS_USER=.mms;                             export INS_USER; # fims output dir
      PREP_DIR=$INS_ROOT/$INS_USER/PREP;         export PREP_DIR; # where is the fits file
      LOG_DIR=$INS_ROOT/$INS_USER/LOG;           export LOG_DIR;  # keep this 
      SET_DIR=$INS_ROOT/$INS_USER/SET;           export SET_DIR;  # keep this 

# copy the MOS longslit masks to the SET directory 
# echo "copy MOS longslit masks to $SET_DIR"


      cp $MMSROOT/src/mos1.034.standard.adf $SET_DIR/.; chmod +w $SET_DIR/mos1.034.standard.adf
      cp $MMSROOT/src/mos1.029.standard.adf $SET_DIR/.; chmod +w $SET_DIR/mos1.029.standard.adf
      cp $MMSROOT/src/mos1.032.standard.adf $SET_DIR/.; chmod +w $SET_DIR/mos1.032.standard.adf
      cp $MMSROOT/src/mos1.065.standard.adf $SET_DIR/.; chmod +w $SET_DIR/mos1.065.standard.adf




# -------------------- PART 2 -- check settings -----------------


if [ -d $INS_ROOT ]
   then
   if $DB; then echo " INS_ROOT            = $INS_ROOT"; fi
   else echo "ERROR: $INS_ROOT does not exist"
        exit
fi


if [ -d $MMSROOT ]
   then
   if $DB; then echo " MMSROOT            = $MMSROOT"; fi
   else echo "ERROR: >$MMSROOT< does not exist"
        echo ">>>>>hint:"
        echo "setenv MMSROOT <..>/work (your MMS installation directory)"
        echo "MMSROOT=<..>/work; export MMSROOT (for bash)"
        echo "setenv MMSROOT ${PWD}/.."
        exit
fi


if [ -d $INS_ROOT/$INS_USER ]
   then
   if $DB; then echo " INS_ROOT/INS_USER   = $INS_ROOT/$INS_USER"; fi
   else echo "ERROR: >$INS_ROOT/$INS_USER< does not exist"
        mkdir $INS_ROOT/$INS_USER
        echo "created ----- $INS_ROOT/$INS_USER"
fi

# where to write the target setup files
# -------------------------------------
if [ -d $SET_DIR ]
   then 
   if $DB; then echo " SET_DIR             = $SET_DIR"; fi
   else echo "ERROR: >$SET_DIR< does not exist"
        mkdir $SET_DIR
        echo "created ----- $SET_DIR"
fi

# where to write the MMS log files
# -------------------------------------
if [ -d $LOG_DIR ]
   then
   if $DB; then echo " LOG_DIR             = $LOG_DIR"; fi
   else echo "ERROR: >$LOG_DIR< does not exist"
        mkdir $LOG_DIR
        echo "created ----- $LOG_DIR"
fi

# from where to load the fits files
# -------------------------------------
if [ -d $PREP_DIR ]
   then
   if $DB; then echo " PREP_DIR            = $PREP_DIR"; fi
   else echo "ERROR: >$PREP_DIR< does not exist"
        mkdir $PREP_DIR
        echo "created ----- $PREP_DIR"
fi


if [ -d $ISF_DIR ]
   then
   if $DB; then echo " ISF_DIR             = $ISF_DIR"; fi
   else echo "ERROR: >$ISF_DIR< does not exist"
        exit
fi


if [ -f $ISF_DIR/$INSTR.isf ]
   then
   if $DB; then echo " $INSTR.isf from       $ISF_DIR/$INSTR.isf"; fi
   else echo "ERROR: >$INSTR.isf< does not exist"
        exit
fi


#-------------- P L U G I N S -------------------------------
        ESO_PLUG=$MMSROOT/lib/libesoPlugins.tcl
        MMS_PLUG=$MMSROOT/lib/libmmsPlugins.tcl
        FRTD_PLUG=$MMSROOT/lib/libfrtdPlugins.tcl
        SKYSEARCH_PLUGIN=$MMS_PLUG/SkySearch_plugin.tcl;       export SKYSEARCH_PLUGIN
        RTD_PLUGIN=$FRTD_PLUG/Rtd_plugin.tcl;                  export RTD_PLUGIN
        SKYCAT_PLUG01=$MMS_PLUG/SkyCat_plugin.tcl
        SKYCAT_PLUG02=$ESO_PLUG/PE_SkyCat_plugin.tcl

if $DB
   then
   echo
   echo " ESO_PLUG            = $ESO_PLUG"
   echo
   #echo " RTD_PLUGIN          = $RTD_PLUGIN"
   echo " SKYSEARCH_PLUGIN    = $SKYSEARCH_PLUGIN"
   echo " SKYCAT_PLUG01       = $SKYCAT_PLUG01"
   echo " SKYCAT_PLUG02       = $SKYCAT_PLUG02"
   echo
   echo " test if file exists"
   echo
   if [ -f $SKYSEARCH_PLUGIN ]; then echo " found: $SKYSEARCH_PLUGIN"; else echo " where? $SKYSEARCH_PLUGIN"; fi
   #if [ -f $RTD_PLUGIN ];       then echo " found: $RTD_PLUGIN";       else echo " where? $RTD_PLUGIN"; fi
   if [ -f $SKYCAT_PLUG01 ];    then echo " found: $SKYCAT_PLUG01";    else echo " where? $SKYCAT_PLUG01"; fi
   if [ -f $SKYCAT_PLUG02 ];    then echo " found: $SKYCAT_PLUG02";    else echo " where? $SKYCAT_PLUG02"; fi
   echo
fi

# join all plugins to one single keyword
SKYCAT_PLUGIN=$SKYCAT_PLUG02:$SKYCAT_PLUG01; export SKYCAT_PLUGIN

if $DB; then echo " SKYCAT_PLUGIN       = >$SKYCAT_PLUGIN<"; fi


# ----------------------------
# print current version number 
# ----------------------------
echo
echo
echo
echo "     W E L C O M E     T O     M M S"
echo "   -----------------------------------"
echo 
echo " +----------------+                +------------------+"
awk ' $4 ~ /mms.sh,v/ { printf(" |  MMS  %8s |----plugin----> | SkyCatTool ", $5) }' $MMSROOT/bin/mms.sh
echo $S_V" |"
echo " +----------------+                +------------------+"

echo
echo   " +------------------------------------------+"
echo   " | INPUT : "$PREP_DIR""
echo   " | OUTPUT: "$SET_DIR""
echo   " | LOGS  : "$LOG_DIR""
echo   " | MMS requires: SkyCat "$S_V""
echo   " +------------------------------------------+"
echo


# ------------------ PART 3 --- start skycat ------------------
echo

echo "skycat $CLS $CLO $private ..."

# call skycat

$MMSROOT/bin/skycat  $CLS $CLO $private
# skycat  $CLS $CLO $private
#
# ___oOo___
