itk::usual MOS {}

namespace eval mos {

   class CONV_WC {

      constructor { args } { eval configure $args }
      destructor { }

      public method coeff_wc {a1 d1}
      public method w2c { wx wy }
      public method c2w { cx cy }

      public variable m_image
      public variable eqx 2000.0

      private variable min_size_arcmin 0.4
      private variable k1
      private variable k2
      private variable k3
      private variable k4
      private variable b1
      private variable b2
      private variable k5
      private variable k6
      private variable k7
      private variable k8
      private variable b3
      private variable b4


   }
   # end of the class CONV_WC



#------------------------------------------------------------------------------------------
   ::itcl::body CONV_WC::coeff_wc {a1 d1} {

      # the older fims versions used the bonsai_matrix which is now done here 
      # a1 and d1 are WCS-deg coords of the mask center 

      # from WCS to CANVAS

      # now we have to extrapolate using some minor vector algebra
      # (x)    (b1)   (k1 k2)   (alp)
      # ( ) =  (  ) + (     ) * (   )
      # (y)    (b2)   (k3 k4)   (dec)

      # first central pixel
      $m_image convert coords $a1 $d1 "deg $eqx" x1 y1  canvas

      # two more test points inside the bonsai image
      # dist = distance from center in  arcsec
      set min_size_deg    [expr $min_size_arcmin/60.0];  # radius in degrees 
      set a2 [expr $a1 + $min_size_deg]
      set d2 $d1
      set a3 $a1
      set d3 [expr $d1 + $min_size_deg]
      # and convert them to canvas
      $m_image convert coords $a2 $d2 "deg $eqx" x2 y2  canvas
      $m_image convert coords $a3 $d3 "deg $eqx" x3 y3  canvas

      # create the matrix elements k1-k4
      # k1 and k3 have the same nominator
      set nom1 [expr ($a1-$a2)*($d2-$d3)-($d1-$d2)*($a2-$a3)]
      set k1 [expr ($x1-$x2)*($d2-$d3)-($x2-$x3)*($d1-$d2)]
      set k3 [expr ($y1-$y2)*($d2-$d3)-($y2-$y3)*($d1-$d2)]
      set k1 [expr $k1/$nom1]; set k3 [expr $k3/$nom1];
      # k2 and k4 have the same nominator
      set nom2 [expr ($d1-$d2)*($a2-$a3)-($d2-$d3)*($a1-$a2)]
      set k2 [expr ($x1-$x2)*($a2-$a3)-($x2-$x3)*($a1-$a2)]
      set k4 [expr ($y1-$y2)*($a2-$a3)-($y2-$y3)*($a1-$a2)]
      set k2 [expr $k2/$nom2];  set k4 [expr $k4/$nom2]

      # now the offset
      set b1 [expr $x1 - $a1*$k1-$d1*$k2]
      set b2 [expr $y1 - $a1*$k3-$d1*$k4]

      # from CANVAS to WCS, the inverse coord conversion

      # now we have to extrapolate using some minor vector algebra
      # (alp)    (b3)   (k5 k6)   (x1)
      # (   ) =  (  ) + (     ) * (  )
      # (dec)    (b4)   (k7 k8)   (y1)
      # create the matrix elements k5-k8
      # k5 and k7 have the same nominator
      set nom1 [expr ($x1-$x2)*($y2-$y3)-($y1-$y2)*($x2-$x3)]
      set k5 [expr ($a1-$a2)*($y2-$y3)-($a2-$a3)*($y1-$y2)]
      set k7 [expr ($d1-$d2)*($y2-$y3)-($d2-$d3)*($y1-$y2)]
      set k5 [expr $k5/$nom1]; set k7 [expr $k7/$nom1];
      # k6 and k8 have the same nominator
      set nom2 [expr ($y1-$y2)*($x2-$x3)-($y2-$y3)*($x1-$x2)]
      set k6 [expr ($a1-$a2)*($x2-$x3)-($a2-$a3)*($x1-$x2)]
      set k8 [expr ($d1-$d2)*($x2-$x3)-($d2-$d3)*($x1-$x2)]
      set k6 [expr $k6/$nom2];  set k8 [expr $k8/$nom2]

      # now the offset
      set b3 [expr $a1 - $x1*$k5-$y1*$k6]
      set b4 [expr $d1 - $x1*$k7-$y1*$k8]

   }

#------------------------------------------------------------------------------------------
   ::itcl::body CONV_WC::w2c { wx wy } {

      return [list [expr $b1+$k1*$wx+$k2*$wy] [expr $b2+$k3*$wx+$k4*$wy] ]

   }

#------------------------------------------------------------------------------------------
   ::itcl::body CONV_WC::c2w { cx cy } {

      return [list [expr $b3+$cx*$k5+$cy*$k6] [expr $b4+$cx*$k7+$cy*$k8] ]

   }

}
# end of namespace
